@@ -4,7 +4,7 @@
 """
 ===============================================================================
 
-    Original code copyright (C) 2009-2021 Rudolf Cardinal (rudolf@pobox.com).
+    Original code copyright (C) 2009-2022 Rudolf Cardinal (rudolf@pobox.com).
 
     This file is part of cardinal_pythonlib.
 
@@ -65,9 +65,10 @@ RunFuncType = Callable
 # Download things
 # =============================================================================
 
-def download_if_not_exists(url: str, filename: str,
-                           skip_cert_verify: bool = True,
-                           mkdir: bool = True) -> None:
+
+def download_if_not_exists(
+    url: str, filename: str, skip_cert_verify: bool = True, mkdir: bool = True
+) -> None:
     """
     Downloads a URL to a file, unless the file already exists.
     """
@@ -77,21 +78,24 @@ def download_if_not_exists(url: str, filename: str,
     if mkdir:
         directory, basename = os.path.split(os.path.abspath(filename))
         mkdir_p(directory)
-    download(url=url,
-             filename=filename,
-             skip_cert_verify=skip_cert_verify)
+    download(url=url, filename=filename, skip_cert_verify=skip_cert_verify)
 
 
 # =============================================================================
 # Git functions
 # =============================================================================
 
-def git_clone(prettyname: str, url: str, directory: str,
-              branch: str = None,
-              commit: str = None,
-              clone_options: List[str] = None,
-              run_func: RunFuncType = None,
-              git_executable: str = None) -> bool:
+
+def git_clone(
+    prettyname: str,
+    url: str,
+    directory: str,
+    branch: str = None,
+    commit: str = None,
+    clone_options: List[str] = None,
+    run_func: RunFuncType = None,
+    git_executable: str = None,
+) -> bool:
     """
     Fetches a Git repository, unless we have it already.
 
@@ -114,21 +118,23 @@ def git_clone(prettyname: str, url: str, directory: str,
     if os.path.isdir(directory):
         log.info(
             "Not re-cloning {} Git repository: using existing source in {}",
-            prettyname, directory)
+            prettyname,
+            directory,
+        )
         return False
-    log.info("Fetching {} source from {} into {}",
-             prettyname, url, directory)
+    log.info("Fetching {} source from {} into {}", prettyname, url, directory)
     gitargs = [git, "clone"] + clone_options
     if branch:
         gitargs += ["--branch", branch]
     gitargs += [url, directory]
     run_func(gitargs)
     if commit:
-        log.info("Resetting {} local Git repository to commit {}",
-                 prettyname, commit)
-        run_func([git,
-                  "-C", directory,
-                  "reset", "--hard", commit])
+        log.info(
+            "Resetting {} local Git repository to commit {}",
+            prettyname,
+            commit,
+        )
+        run_func([git, "-C", directory, "reset", "--hard", commit])
         # Using a Git repository that's not in the working directory:
         # https://stackoverflow.com/questions/1386291/git-git-dir-not-working-as-expected  # noqa
     return True
@@ -148,6 +154,7 @@ def git_clone(prettyname: str, url: str, directory: str,
 # tar functions
 # =============================================================================
 
+
 def tar_supports_force_local_switch(tar_executable: str) -> bool:
     """
     Does ``tar`` support the ``--force-local`` switch? We ask it.
@@ -156,15 +163,17 @@ def tar_supports_force_local_switch(tar_executable: str) -> bool:
     return "--force-local" in tarhelp
 
 
-def untar_to_directory(tarfile: str,
-                       directory: str,
-                       verbose: bool = False,
-                       gzipped: bool = False,
-                       skip_if_dir_exists: bool = True,
-                       run_func: RunFuncType = None,
-                       chdir_via_python: bool = True,
-                       tar_executable: str = None,
-                       tar_supports_force_local: bool = None) -> None:
+def untar_to_directory(
+    tarfile: str,
+    directory: str,
+    verbose: bool = False,
+    gzipped: bool = False,
+    skip_if_dir_exists: bool = True,
+    run_func: RunFuncType = None,
+    chdir_via_python: bool = True,
+    tar_executable: str = None,
+    tar_supports_force_local: bool = None,
+) -> None:
     """
     Unpacks a TAR file into a specified directory.
 
@@ -194,8 +203,11 @@ def untar_to_directory(tarfile: str,
             (build 17063+) tar doesn't.
     """
     if skip_if_dir_exists and os.path.isdir(directory):
-        log.info("Skipping extraction of {} as directory {} exists",
-                 tarfile, directory)
+        log.info(
+            "Skipping extraction of {} as directory {} exists",
+            tarfile,
+            directory,
+        )
         return
     tar = which_and_require(tar_executable or "tar")
     if tar_supports_force_local is None:
@@ -223,6 +235,7 @@ def untar_to_directory(tarfile: str,
 # Environment functions
 # =============================================================================
 
+
 def make_copy_paste_env(env: Dict[str, str]) -> str:
     """
     Convert an environment into a set of commands that can be copied/pasted, on
@@ -230,14 +243,13 @@ def make_copy_paste_env(env: Dict[str, str]) -> str:
     """
     windows = platform.system() == "Windows"
     cmd = "set" if windows else "export"
-    return (
-        "\n".join(
-            "{cmd} {k}={v}".format(
-                cmd=cmd,
-                k=k,
-                v=env[k] if windows else subprocess.list2cmdline([env[k]])
-            ) for k in sorted(env.keys())
+    return "\n".join(
+        "{cmd} {k}={v}".format(
+            cmd=cmd,
+            k=k,
+            v=env[k] if windows else subprocess.list2cmdline([env[k]]),
         )
+        for k in sorted(env.keys())
     )
     # Note that even subprocess.list2cmdline() will put needless quotes in
     # here, whereas SET is happy with e.g. SET x=C:\Program Files\somewhere;
@@ -249,16 +261,19 @@ def make_copy_paste_env(env: Dict[str, str]) -> str:
 # Run subprocesses in a very verbose way
 # =============================================================================
 
-def run(args: List[str],
-        env: Dict[str, str] = None,
-        capture_stdout: bool = False,
-        echo_stdout: bool = True,
-        capture_stderr: bool = False,
-        echo_stderr: bool = True,
-        debug_show_env: bool = True,
-        encoding: str = sys.getdefaultencoding(),
-        allow_failure: bool = False,
-        **kwargs) -> Tuple[str, str]:
+
+def run(
+    args: List[str],
+    env: Dict[str, str] = None,
+    capture_stdout: bool = False,
+    echo_stdout: bool = True,
+    capture_stderr: bool = False,
+    echo_stderr: bool = True,
+    debug_show_env: bool = True,
+    encoding: str = sys.getdefaultencoding(),
+    allow_failure: bool = False,
+    **kwargs
+) -> Tuple[str, str]:
     """
     Runs an external process, announcing it.
 
@@ -306,7 +321,7 @@ def run(args: List[str],
             "{env}\n"
             "{esep}",
             esep=esep,
-            env=make_copy_paste_env(effective_env)
+            env=make_copy_paste_env(effective_env),
         )
     log.info(
         "Launching external command:\n"
@@ -318,7 +333,7 @@ def run(args: List[str],
         csep=csep,
         cwd=cwd,
         cmd=copy_paste_cmd,
-        pyargs=args
+        pyargs=args,
     )
     try:
         with io.StringIO() as out, io.StringIO() as err:
@@ -332,24 +347,28 @@ def run(args: List[str],
                 stderr_targets.append(err)
             if echo_stderr:
                 stderr_targets.append(sys.stderr)
-            retcode = teed_call(args,
-                                stdout_targets=stdout_targets,
-                                stderr_targets=stderr_targets,
-                                encoding=encoding,
-                                env=env,
-                                **kwargs)
+            retcode = teed_call(
+                args,
+                stdout_targets=stdout_targets,
+                stderr_targets=stderr_targets,
+                encoding=encoding,
+                env=env,
+                **kwargs
+            )
             stdout = out.getvalue()
             stderr = err.getvalue()
             if retcode != 0 and not allow_failure:
                 # subprocess.check_call() and check_output() raise
                 # CalledProcessError if the called process returns a non-zero
                 # return code.
-                raise subprocess.CalledProcessError(returncode=retcode,
-                                                    cmd=args,
-                                                    output=stdout,
-                                                    stderr=stderr)
-        log.debug("\n{csep}\nFINISHED SUCCESSFULLY: {cmd}\n{csep}",
-                  cmd=copy_paste_cmd, csep=csep)
+                raise subprocess.CalledProcessError(
+                    returncode=retcode, cmd=args, output=stdout, stderr=stderr
+                )
+        log.debug(
+            "\n{csep}\nFINISHED SUCCESSFULLY: {cmd}\n{csep}",
+            cmd=copy_paste_cmd,
+            csep=csep,
+        )
         return stdout, stderr
     except FileNotFoundError:
         require_executable(args[0])  # which is missing, so we'll see some help
@@ -366,13 +385,16 @@ def run(args: List[str],
             cwd=cwd,
             env=make_copy_paste_env(effective_env),
             cmd=copy_paste_cmd,
-            pyargs=args
+            pyargs=args,
         )
         raise
 
 
-def fetch(args: List[str], env: Dict[str, str] = None,
-          encoding: str = sys.getdefaultencoding()) -> str:
+def fetch(
+    args: List[str],
+    env: Dict[str, str] = None,
+    encoding: str = sys.getdefaultencoding(),
+) -> str:
     """
     Run a command and returns its stdout.
 
@@ -385,7 +407,12 @@ def fetch(args: List[str], env: Dict[str, str] = None,
         the command's ``stdout`` output
 
     """
-    stdout, _ = run(args, env=env, capture_stdout=True,
-                    echo_stdout=False, encoding=encoding)
+    stdout, _ = run(
+        args,
+        env=env,
+        capture_stdout=True,
+        echo_stdout=False,
+        encoding=encoding,
+    )
     log.debug("{}", stdout)
     return stdout
