@@ -4,7 +4,7 @@
 """
 ===============================================================================
 
-    Original code copyright (C) 2009-2021 Rudolf Cardinal (rudolf@pobox.com).
+    Original code copyright (C) 2009-2022 Rudolf Cardinal (rudolf@pobox.com).
 
     This file is part of cardinal_pythonlib.
 
@@ -48,11 +48,14 @@ log = get_brace_style_log_with_null_handler(__name__)
 # https://stackoverflow.com/questions/49547/making-sure-a-web-page-is-not-cached-across-all-browsers  # noqa
 # https://stackoverflow.com/questions/3859097/how-to-add-http-headers-in-wsgi-middleware  # noqa
 
+
 def add_never_cache_headers(headers: TYPE_WSGI_RESPONSE_HEADERS) -> None:
     """
     Adds WSGI headers to say "never cache this response".
     """
-    headers.append(("Cache-Control", "no-cache, no-store, must-revalidate"))  # HTTP 1.1  # noqa
+    headers.append(
+        ("Cache-Control", "no-cache, no-store, must-revalidate")
+    )  # HTTP 1.1  # noqa
     headers.append(("Pragma", "no-cache"))  # HTTP 1.0
     headers.append(("Expires", "0"))  # Proxies
 
@@ -65,15 +68,16 @@ class DisableClientSideCachingMiddleware(object):
     def __init__(self, app: TYPE_WSGI_APP) -> None:
         self.app = app
 
-    def __call__(self,
-                 environ: TYPE_WSGI_ENVIRON,
-                 start_response: TYPE_WSGI_START_RESPONSE) \
-            -> TYPE_WSGI_APP_RESULT:
-
-        def custom_start_response(status: TYPE_WSGI_STATUS,
-                                  headers: TYPE_WSGI_RESPONSE_HEADERS,
-                                  exc_info: TYPE_WSGI_EXC_INFO = None) \
-                -> TYPE_WSGI_START_RESP_RESULT:
+    def __call__(
+        self,
+        environ: TYPE_WSGI_ENVIRON,
+        start_response: TYPE_WSGI_START_RESPONSE,
+    ) -> TYPE_WSGI_APP_RESULT:
+        def custom_start_response(
+            status: TYPE_WSGI_STATUS,
+            headers: TYPE_WSGI_RESPONSE_HEADERS,
+            exc_info: TYPE_WSGI_EXC_INFO = None,
+        ) -> TYPE_WSGI_START_RESP_RESULT:
             add_never_cache_headers(headers)
             log.debug("HTTP status {}, headers {}", status, headers)
             return start_response(status, headers, exc_info)
